@@ -5,9 +5,9 @@ from ..ruler import StateBase
 
 
 class StateCore(StateBase):
-    def __init__(self, src: str, md, env):
+    def __init__(self, src: str, md, env, tokens=None):
         self.src = src
         self.md = md  # link to parser instance
         self.env = env
-        self.tokens: List[Token] = []
+        self.tokens: List[Token] = tokens or []
         self.inlineMode = False
