@@ -43,9 +43,12 @@ def backtick(state: StateInline, silent: bool):
                 token = state.push("code_inline", "code", 0)
                 token.markup = marker
                 token.content = state.src[pos:matchStart].replace("\n", " ")
-                if token.content.startswith(" ") and token.content.endswith(" "):
+                if (
+                    token.content.startswith(" ")
+                    and token.content.endswith(" ")
+                    and len(token.content.strip()) > 0
+                ):
                     token.content = token.content[1:-1]
-
             state.pos = matchEnd
             return True
 
